@@ -10,7 +10,7 @@ logging.basicConfig(level=logging.DEBUG,
                     format='%(asctime)s,%(msecs)d %(levelname)-8s [%(filename)s:%(lineno)d] %(message)s',
                     datefmt='%m-%d %H:%M')
 
-env_secret = '28vwvqjS7Ee6TcC72FKftgo3_umZrwHEee8COMmbLp1A'
+env_secret = 'aM8NhGoaRUiADNLI-RO8Ug1mDiQeOD_kyUPu9s2DQBuw'
 
 config = Config(env_secret, event_url='http://localhost:5100', streaming_url='ws://localhost:5100')
 
